@@ -5,35 +5,34 @@
 ;; Copyright © 2024 Free Software Foundation, Inc.
 ;; Copyright © 2025 Mekeor Melire
 
-;; Author:
-;;   Adam Topaz <topaz@ualberta.ca>
-;;   Akira Komamura <akira.komamura@gmail.com>
-;;   Bao Zhiyuan <bzy_sustech@foxmail.com>
-;;   Daniel Selsam <daniel.selsam@protonmail.com>
-;;   Gabriel Ebner <gebner@gebner.org>
-;;   Henrik Böving <hargonix@gmail.com>
-;;   Hongyu Ouyang  <oyhy0214@163.com>
-;;   Jakub Bartczuk <bartczukkuba@gmail.com>
-;;   Leonardo de Moura <leonardo@microsoft.com>
-;;   Mauricio Collares <mauricio@collares.org>
-;;   Mekeor Melire <mekeor@posteo.de>
-;;   Philip Kaludercic <philipk@posteo.net>
-;;   Richard Copley <buster@buster.me.uk>
-;;   Sebastian Ullrich <sebasti@nullri.ch>
-;;   Siddharth Bhat <siddu.druid@gmail.com>
-;;   Simon Hudon <simon.hudon@gmail.com>
-;;   Soonho Kong <soonhok@cs.cmu.edu>
-;;   Tomáš Skřivan <skrivantomas@seznam.cz>
-;;   Wojciech Nawrocki <wjnawrocki@protonmail.com>
-;;   Yael Dillies <yael.dillies@gmail.com>
-;;   Yury G. Kudryashov <urkud@urkud.name>
+;; Author: Adam Topaz <topaz@ualberta.ca>
+;;         Akira Komamura <akira.komamura@gmail.com>
+;;         Bao Zhiyuan <bzy_sustech@foxmail.com>
+;;         Daniel Selsam <daniel.selsam@protonmail.com>
+;;         Gabriel Ebner <gebner@gebner.org>
+;;         Henrik Böving <hargonix@gmail.com>
+;;         Hongyu Ouyang <oyhy0214@163.com>
+;;         Jakub Bartczuk <bartczukkuba@gmail.com>
+;;         Leonardo de Moura <leonardo@microsoft.com>
+;;         Mauricio Collares <mauricio@collares.org>
+;;         Mekeor Melire <mekeor@posteo.de>
+;;         Philip Kaludercic <philipk@posteo.net>
+;;         Richard Copley <buster@buster.me.uk>
+;;         Sebastian Ullrich <sebasti@nullri.ch>
+;;         Siddharth Bhat <siddu.druid@gmail.com>
+;;         Simon Hudon <simon.hudon@gmail.com>
+;;         Soonho Kong <soonhok@cs.cmu.edu>
+;;         Tomáš Skřivan <skrivantomas@seznam.cz>
+;;         Wojciech Nawrocki <wjnawrocki@protonmail.com>
+;;         Yael Dillies <yael.dillies@gmail.com>
+;;         Yury G. Kudryashov <urkud@urkud.name>
 ;; Keywords: languages
 ;; Maintainer: Mekeor Melire <mekeor@posteo.de>
 ;; Package-Requires: ((emacs "29.1"))
 ;; SPDX-License-Identifier: Apache-2.0 AND GPL-3.0-only
 ;; URL: https://codeberg.org/mekeor/nael
-;; Package-Version: 0.6.4
-;; Package-Revision: 5524ce167c3f
+;; Package-Version: 0.8.1
+;; Package-Revision: 3ee1cf286dc1
 
 ;; This is licensed under GNU General Public License (version 3 only),
 ;; see LICENSE.GPL3.  To be precise, it is licensed under Apache-2.0,
@@ -41,10 +40,15 @@
 
 ;;; Commentary:
 
-;; `nael-mode' is a major mode for Lean.
-
-;; Nael is forked from Lean4-Mode:
-;; https://github.com/leanprover-community/lean4-mode
+;; `nael-mode' is a major mode for the Lean language.  For more
+;; information, read the manual:
+;;
+;; - As Org file `README.org' in the `nael' folder or repository.
+;;
+;; - After installation, as local Info manual per C-h i d nael RET or
+;;   (info "(nael) Top")
+;;
+;; - As HTML webpage at <https://codeberg.org/mekeor/nael>.
 
 ;;; Code:
 
@@ -526,11 +530,26 @@ least evaluated an autoload statement for
   ;; Flymake:
   (nael-flymake-configure))
 
-;;;###autoload
-(add-to-list 'auto-mode-alist (cons "\\.lean\\'" 'nael-mode))
-
+;; Lean language specification requires UTF-8 encoding.
 (modify-coding-system-alist 'file "\\.lean\\'" 'utf-8)
 
+;;;; Association:
+
+;;;###autoload
+(add-to-list 'auto-mode-alist
+             (cons "\\.lean\\'" 'nael-mode))
+
+(with-eval-after-load 'org-src
+  (add-to-list 'org-src-lang-modes
+               (cons "lean" 'nael)))
+
+;; If the code that requires `markdown-mode' grows, we will extract it
+;; into a new package that depends on it.  But a single expression is
+;; not worth a package.
+(with-eval-after-load 'markdown-mode
+  (add-to-list 'markdown-code-lang-modes
+               (cons "lean" 'nael-mode)))
+
 (provide 'nael)
 
 ;;; nael.el ends here
